==> kognic_io-1.0.2-py3-none-any.whl: kognic/io/resources/input/lidars.py <==
import logging
from typing import Optional, List

import kognic.io.model.input.lidars as model
from kognic.io.model.input import CreateInputResponse
from kognic.io.model.input.feature_flags import FeatureFlags
from kognic.io.resources.abstract import CreateableIOResource

log = logging.getLogger(__name__)


class Lidars(CreateableIOResource):
    path = 'lidars'

    def create(
        self,
        lidars: model.Lidars,
        project: Optional[str] = None,
        batch: Optional[str] = None,
        annotation_types: Optional[List[str]] = None,
        dryrun: bool = False,
        feature_flags: Optional[FeatureFlags] = None
    ) -> Optional[CreateInputResponse]:
        """
        Upload files and create an input of type ``Lidars``.

        :param lidars: class containing 3D resources that constitute the input
        :param project: project to add input to
        :param batch: batch, defaults to latest open batch
        :param annotation_types: annotation types for which to produce annotations for. Defaults to `None` (corresponds to all available annotation types). Passing an empty list will result in the same behaviour as passing `None`.
        :param dryrun: If True the files/metadata will be validated but no input job will be created.
        :param feature_flags Optional set of feature flags to control the input creation process.
        :returns CreateInputResponse: Class containing id of the created input job, or `None` if dryrun.
        """

        imu_data = lidars.imu_data
        payload = lidars.to_dict()

        response = self._post_input_request(
            self.path,
            payload,
            project=project,
            batch=batch,
            annotation_types=annotation_types,
            imu_data=imu_data,
            dryrun=dryrun,
            feature_flags=feature_flags
        )

        if dryrun:
            return None

        log.info(f"Created inputs for files with uuid={response.input_uuid}")
        return CreateInputResponse.from_input_job_response(response)

==> kognic_io-1.3.0-py3-none-any.whl: kognic/io/resources/input/lidars.py <==
import logging
from typing import Optional, List

import kognic.io.model.input.lidars as model
from kognic.io.model.input import CreateInputResponse
from kognic.io.model.input.feature_flags import FeatureFlags
from kognic.io.resources.abstract import CreateableIOResource

log = logging.getLogger(__name__)


class Lidars(CreateableIOResource):
    path = 'lidars'

    def create(
        self,
        lidars: model.Lidars,
        project: Optional[str] = None,
        batch: Optional[str] = None,
        annotation_types: Optional[List[str]] = None,
        dryrun: bool = False,
        feature_flags: Optional[FeatureFlags] = None
    ) -> Optional[CreateInputResponse]:
        """
        Upload files and create an input of type ``Lidars``.

        :param lidars: class containing 3D resources that constitute the input
        :param project: project to add input to
        :param batch: batch, defaults to latest open batch
        :param annotation_types: annotation types for which to produce annotations for. Defaults to `None` (corresponds
         to all available annotation types). Passing an empty list will result in the same behaviour as passing `None`.
        :param dryrun: If True the files/metadata will be validated but no input job will be created.
        :param feature_flags Optional set of feature flags to control the input creation process.
        :returns CreateInputResponse: Class containing id of the created input job, or `None` if dryrun.
        """
        if not isinstance(lidars, model.Lidars):
            raise ValueError(f"Cannot create a {type(lidars)} via this endpoint")

        response = self._post_input_request(
            self.path,
            lidars.to_dict(),
            project=project,
            batch=batch,
            annotation_types=annotation_types,
            imu_data=lidars.imu_data,
            resources=lidars.resources,
            dryrun=dryrun,
            feature_flags=feature_flags
        )

        if dryrun:
            return None

        log.info(f"Created inputs for files with uuid={response.input_uuid}")
        return CreateInputResponse.from_input_job_response(response)
